import { Redirect } from '@shopify/app-bridge-core/actions';

function getResourceUrl(url, section) {
    var name = section.name, resource = section.resource;
    switch (name) {
        case Redirect.ResourceType.Product:
            return getProductUrl(url, resource);
        case Redirect.ResourceType.Collection:
            return getCollectionUrl(url, resource);
        case Redirect.ResourceType.Order:
            return getOrderUrl(url, resource);
        case Redirect.ResourceType.Discount:
            return getDiscountUrl(url, resource);
        case Redirect.ResourceType.Customer:
            return getCustomerUrl(url, resource);
    }
}
function getProductUrl(url, resource) {
    if (!resource) {
        return url.productIndex();
    }
    if (Redirect.isProductVariantResourcePayload(resource)) {
        var _a = resource, id = _a.id, variant = _a.variant;
        if (Redirect.isResourcePayload(variant)) {
            return url.productVariantDetails(id, variant.id);
        }
        if (Redirect.isCreateResourcePayload(variant)) {
            return url.productVariantNew(id);
        }
    }
    if (Redirect.isResourcePayload(resource)) {
        return url.productDetails(resource.id);
    }
    if (Redirect.isCreateResourcePayload(resource)) {
        return url.productNew();
    }
}
function getCollectionUrl(url, resource) {
    if (!resource) {
        return url.collectionIndex();
    }
    if (Redirect.isResourcePayload(resource)) {
        return url.collectionShow(resource.id);
    }
    if (Redirect.isCreateResourcePayload(resource)) {
        return url.collectionNew();
    }
}
function getDiscountUrl(url, resource) {
    if (!resource) {
        return url.discountIndex();
    }
    if (Redirect.isResourcePayload(resource)) {
        return url.discountShow(resource.id);
    }
    if (Redirect.isCreateResourcePayload(resource)) {
        return url.discountNew();
    }
}
function getCustomerUrl(url, resource) {
    if (!resource) {
        return url.customerIndex();
    }
    if (Redirect.isResourcePayload(resource)) {
        return url.customerShow(resource.id);
    }
    if (Redirect.isCreateResourcePayload(resource)) {
        return url.customerCreate();
    }
}
function getOrderUrl(url, resource) {
    if (!resource) {
        return url.orderIndex();
    }
    if (Redirect.isResourcePayload(resource)) {
        return url.orderShow(resource.id);
    }
    if (Redirect.isCreateResourcePayload(resource)) {
        return url.orderNew();
    }
}

export { getResourceUrl as default, getCollectionUrl, getCustomerUrl, getDiscountUrl, getOrderUrl, getProductUrl };
