import { __assign } from 'tslib';
import { PermissionType } from '@shopify/app-bridge-core/client';
import * as Actions from '@shopify/app-bridge-core/actions';
import mergeProps from '@shopify/app-bridge-core/actions/merge';
import { getPermissionKey } from '@shopify/app-bridge-core/actions/validator';
import { Context } from '@shopify/app-bridge-core';
import { Group } from '@shopify/app-bridge-core/actions/types';
import { getGroupActionType } from '../utilities.js';

var _a, _b, _c;
var APP_REDIRECT_KEY = getPermissionKey(Actions.Redirect.Action.APP);
var FEATURES_UPDATE_KEY = getPermissionKey(Actions.Features.Action.UPDATE);
var FEATURES_REQUEST_KEY = getPermissionKey(Actions.Features.Action.REQUEST);
var FEATURES_REQUEST_UPDATE_KEY = getPermissionKey(Actions.Features.Action.REQUEST_UPDATE);
var DEFAULT_FEATURES_STATE = (_a = {},
    _a[FEATURES_UPDATE_KEY] = {
        Dispatch: false,
        Subscribe: true,
    },
    _a[FEATURES_REQUEST_KEY] = {
        Dispatch: true,
        Subscribe: false,
    },
    _a[FEATURES_REQUEST_UPDATE_KEY] = {
        Dispatch: false,
        Subscribe: true,
    },
    _a);
var AUTH_CODE_REQUEST_KEY = getPermissionKey(Actions.AuthCode.Action.REQUEST);
var AUTH_CODE_RESPOND_KEY = getPermissionKey(Actions.AuthCode.Action.RESPOND);
var AUTH_CODE_FEATURES_STATE = (_b = {},
    _b[AUTH_CODE_REQUEST_KEY] = {
        Dispatch: true,
        Subscribe: true,
    },
    _b[AUTH_CODE_RESPOND_KEY] = {
        Dispatch: false,
        Subscribe: true,
    },
    _b);
var SESSION_TOKEN_REQUEST_KEY = getPermissionKey(Actions.SessionToken.Action.REQUEST);
var SESSION_TOKEN_RESPOND_KEY = getPermissionKey(Actions.SessionToken.Action.RESPOND);
var SESSION_TOKEN_FEATURES_STATE = (_c = {},
    _c[SESSION_TOKEN_REQUEST_KEY] = {
        Dispatch: true,
        Subscribe: true,
    },
    _c[SESSION_TOKEN_RESPOND_KEY] = {
        Dispatch: false,
        Subscribe: true,
    },
    _c);
var DEFAULT_ENABLED_GROUPS = [Group.Button, Group.ButtonGroup, Group.Error];
var defaultFeaturesStore = getDefaultFeatures();
function getFeaturesPermissions() {
    var _a, _b, _c, _d;
    var navigationFeature = setFeatureByActionGroup(Group.Navigation, true);
    var modalNavigationFeature = __assign(__assign({}, navigationFeature), (_a = {}, _a[APP_REDIRECT_KEY] = {
        Dispatch: true,
        Subscribe: false,
    }, _a));
    var mainPermissions = (_b = {},
        _b[Group.AuthCode] = AUTH_CODE_FEATURES_STATE,
        _b[Group.Button] = setFeatureByActionGroup(Group.Button, true),
        _b[Group.ButtonGroup] = setFeatureByActionGroup(Group.ButtonGroup, true),
        _b[Group.Cart] = setFeatureByActionGroup(Group.Cart, true),
        _b[Group.Client] = setFeatureByActionGroup(Group.Client, true),
        _b[Group.ContextualSaveBar] = setFeatureByActionGroup(Group.ContextualSaveBar, true),
        _b[Group.Error] = setFeatureByActionGroup(Group.Error, true),
        _b[Group.Features] = setFeatureByActionGroup(Group.Features, true),
        _b[Group.FeedbackModal] = setFeatureByActionGroup(Group.FeedbackModal, true),
        _b[Group.Fullscreen] = setFeatureByActionGroup(Group.Fullscreen, true),
        _b[Group.LeaveConfirmation] = setFeatureByActionGroup(Group.LeaveConfirmation, true),
        _b[Group.Link] = setFeatureByActionGroup(Group.Link, true),
        _b[Group.Loading] = setFeatureByActionGroup(Group.Loading, true),
        _b[Group.MarketingExternalActivityTopBar] = setFeatureByActionGroup(Group.MarketingExternalActivityTopBar, true),
        _b[Group.Menu] = setFeatureByActionGroup(Group.Menu, true),
        _b[Group.Modal] = setFeatureByActionGroup(Group.Modal, true),
        _b[Group.Navigation] = navigationFeature,
        _b[Group.Performance] = setFeatureByActionGroup(Group.Performance, true),
        _b[Group.Pos] = setFeatureByActionGroup(Group.Pos, true),
        _b[Group.Print] = setFeatureByActionGroup(Group.Print, true),
        _b[Group.ResourcePicker] = setFeatureByActionGroup(Group.ResourcePicker, true),
        _b[Group.Scanner] = setFeatureByActionGroup(Group.Scanner, true),
        _b[Group.SessionToken] = SESSION_TOKEN_FEATURES_STATE,
        _b[Group.Share] = setFeatureByActionGroup(Group.Share, true),
        _b[Group.TitleBar] = setFeatureByActionGroup(Group.TitleBar, true),
        _b[Group.Toast] = setFeatureByActionGroup(Group.Toast, true),
        _b[Group.unstable_Picker] = setFeatureByActionGroup(Group.unstable_Picker, true),
        _b[Group.WebVitals] = setFeatureByActionGroup(Group.WebVitals, true),
        _b);
    var modalPermissions = mergeProps(mainPermissions, (_c = {},
        // Should we enable fullscreen here?
        _c[Group.Fullscreen] = setFeatureByActionGroup(Group.Fullscreen, false),
        _c[Group.Navigation] = modalNavigationFeature,
        _c[Group.Print] = setFeatureByActionGroup(Group.Print, false),
        _c));
    return _d = {},
        _d[Context.Main] = mainPermissions,
        _d[Context.Modal] = modalPermissions,
        _d;
}
function setFeatureByActionGroup(group, value) {
    if (value === void 0) { value = false; }
    return setFeature(getGroupActionType(group), value);
}
/**
 * Map an action enum to the given permission
 * @public
 * @param actions - the actions enum
 * @param value - the permission to set
 * @returns an object with keys mapped to the actions and value set to the given permission
 */
function setFeature(actions, value) {
    if (value === void 0) { value = false; }
    var features = {};
    var permission = value;
    if (typeof value === 'boolean') {
        permission = { Dispatch: value, Subscribe: value };
    }
    var actionsAsArray = Array.isArray(actions) ? actions : [actions];
    actionsAsArray.forEach(function (action) {
        Object.values(action).forEach(function (value) {
            features[getPermissionKey(value)] = permission;
        });
    });
    return features;
}
/**
 * Returns the updated feature state
 * @param state - the current state
 * @param action - the update action with partial features in the payload
 * @internal
 * */
function featuresReducer(state, action) {
    if (state === void 0) { state = defaultFeaturesStore; }
    switch (action.type) {
        case Actions.Features.Action.UPDATE: {
            var payload = action.payload;
            return mergeProps(state, getUpdatePayload(payload));
        }
        default:
            return state;
    }
}
function normalizePermissions(features) {
    if (features === void 0) { features = {}; }
    return Object.keys(features).reduce(function (acc, group) {
        var _a;
        var featureGroup = features[group];
        if (!featureGroup) {
            return acc;
        }
        var actionPermissions = Object.keys(featureGroup).reduce(function (actionAcc, action) {
            var _a, _b;
            var permission = featureGroup[action];
            return __assign(__assign({}, actionAcc), (_a = {}, _a[action] = hasNewPermission(permission)
                ? permission
                : (_b = {},
                    _b[PermissionType.Dispatch] = permission,
                    _b[PermissionType.Subscribe] = permission,
                    _b), _a));
        }, {});
        return __assign(__assign({}, acc), (_a = {}, _a[group] = actionPermissions, _a));
    }, {});
}
function hasNewPermission(permission) {
    return (Object.prototype.hasOwnProperty.call(permission, PermissionType.Dispatch) &&
        Object.prototype.hasOwnProperty.call(permission, PermissionType.Subscribe));
}
function getUpdatePayload(payload) {
    var _a, _b;
    if (Object.prototype.hasOwnProperty.call(payload, Context.Main) ||
        Object.prototype.hasOwnProperty.call(payload, Context.Modal)) {
        return _a = {},
            _a[Context.Main] = normalizePermissions(payload[Context.Main]),
            _a[Context.Modal] = normalizePermissions(payload[Context.Modal]),
            _a;
    }
    return _b = {},
        _b[Context.Main] = normalizePermissions(payload),
        _b;
}
function getDefaultFeatures() {
    var _a;
    var features = enumValues(Group).reduce(function (acc, group) {
        var _a;
        var castedGroup = group;
        var permissions = group === Group.Features
            ? DEFAULT_FEATURES_STATE
            : setFeature(getGroupActionType(castedGroup), DEFAULT_ENABLED_GROUPS.includes(castedGroup));
        return __assign(__assign({}, acc), (_a = {}, _a[castedGroup] = permissions, _a));
    }, {});
    return _a = {},
        _a[Context.Main] = features,
        _a[Context.Modal] = features,
        _a;
}
function getDefaultAsyncFeatures() {
    var _a;
    var features = enumValues(Group).reduce(function (acc, group) {
        var _a;
        var castedGroup = group;
        var permissions = group === Group.Features
            ? DEFAULT_FEATURES_STATE
            : setFeature(getGroupActionType(castedGroup), DEFAULT_ENABLED_GROUPS.includes(castedGroup));
        return __assign(__assign({}, acc), (_a = {}, _a[castedGroup] = permissions, _a));
    }, {});
    return _a = {},
        _a[Context.Main] = features,
        _a[Context.Modal] = features,
        _a;
}
var defaultAsyncFeaturesStore = getDefaultAsyncFeatures();
/**
 * Returns the updated feature state
 * @param state - the current state
 * @param action - the update action with partial features in the payload
 * @internal
 * */
function asyncFeaturesReducer(state, action) {
    if (state === void 0) { state = defaultAsyncFeaturesStore; }
    return featuresReducer(state, action);
}
/**
 * Returns the features state with the provided group(s) enabled
 * The permission is set for both Main and Modal context
 * according to the default feature permission rules
 * @argument keys - the group(s) to enable the feature permission
 * @public
 * */
function setFeaturesAvailable() {
    var _a;
    var features = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        features[_i] = arguments[_i];
    }
    var _b = getFeaturesPermissions(), Modal = _b.Modal, Main = _b.Main;
    var modalPermission = features.reduce(function (acc, curr) {
        var _a;
        return __assign(__assign({}, acc), (_a = {}, _a[curr] = Modal && Modal[curr], _a));
    }, {});
    var mainPermission = features.reduce(function (acc, curr) {
        var _a;
        return __assign(__assign({}, acc), (_a = {}, _a[curr] = Main && Main[curr], _a));
    }, {});
    return mergeProps(defaultFeaturesStore, (_a = {},
        _a[Context.Main] = mainPermission,
        _a[Context.Modal] = modalPermission,
        _a));
}
/**
 * Returns typed enum values as an array
 * @internal
 */
function enumValues(enumObject) {
    return Object.keys(enumObject).map(function (key) { return enumObject[key]; });
}

export { asyncFeaturesReducer, featuresReducer as default, defaultFeaturesStore, setFeature, setFeaturesAvailable };
