import { __assign } from 'tslib';
import { combineReducers } from 'redux';
import '@shopify/app-bridge-core/actions';
import featuresReducer, { defaultFeaturesStore } from './features/reducer.js';
import '@shopify/app-bridge-core/actions/Toast';
import '@remote-ui/core';
import { wrapReducers, resetStateReducer, resetAppReducer } from './utilities.js';
import toastReducer, { defaultToastStore } from './toast/reducer.js';
import loadingReducer, { defaultLoadingStore } from './loading/reducer.js';
import './modal/actionCreators.js';
import modalReducer, { defaultModalStore } from './modal/reducer.js';
import '@shopify/app-bridge-core/actions/TitleBar';
import '@shopify/app-bridge-core/actions/ButtonGroup';
import '@shopify/app-bridge-core/actions/helper';
import '@shopify/app-bridge-core/actions/uuid';
import titleBarReducer, { defaultTitlebarStore } from './titleBar/reducer.js';
import '@shopify/app-bridge-core/actions/Navigation/Redirect';
import './resourcePicker/actionCreators.js';
import resourcePickerReducer, { defaultResourcePickerStore } from './resourcePicker/reducer.js';
import './navigation/actionCreators.js';
import navigationReducer, { defaultNavigationStore } from './navigation/reducer.js';
import menuReducer, { defaultMenuStore } from './menu/index.js';
import posReducer, { defaultPOSStore } from './pos/reducer.js';
import staffMemberReducer, { defaultStaffMemberStore } from './staffMember/reducer.js';
import legacyReducer, { defaultLegacyStore } from './legacy/index.js';
import fullscreenReducer, { defaultFullscreenStore } from './fullscreen/index.js';
import contextualSaveBarReducer, { defaultContextualSaveBarStore } from './contextualSaveBar/index.js';
import '@shopify/app-bridge-core/actions/Picker';
import './picker/actionCreators.js';
import pickerReducer, { defaultPickerStore } from './picker/reducer.js';

/**
 * The interface for the app's default state
 * @internal
 */
var defaultStore = {
    contextualSaveBar: defaultContextualSaveBarStore,
    features: defaultFeaturesStore,
    toast: defaultToastStore,
    loading: defaultLoadingStore,
    modal: defaultModalStore,
    titleBar: defaultTitlebarStore,
    pos: defaultPOSStore,
    resourcePicker: defaultResourcePickerStore,
    menu: defaultMenuStore,
    navigation: defaultNavigationStore,
    staffMember: defaultStaffMemberStore,
    isLegacy: defaultLegacyStore,
    isFullscreen: defaultFullscreenStore,
    unstablePicker: defaultPickerStore,
};
var appStateReducers = wrapReducers({
    contextualSaveBar: contextualSaveBarReducer,
    toast: toastReducer,
    loading: loadingReducer,
    modal: modalReducer,
    titleBar: titleBarReducer,
    resourcePicker: resourcePickerReducer,
    menu: menuReducer,
    navigation: navigationReducer,
    isFullscreen: fullscreenReducer,
    unstablePicker: pickerReducer,
}, resetStateReducer);
/**
 * The combined Redux reducers
 * @internal
 */
function getReducers() {
    return combineReducers(wrapReducers(__assign({ features: featuresReducer, pos: posReducer, staffMember: staffMemberReducer, isLegacy: legacyReducer }, appStateReducers), resetAppReducer));
}

export { defaultStore, getReducers };
