import type { Location, Navigate } from '@shopify/app-bridge-core/actions/Navigation/Redirect';
import type { FeatureWithRouterApi } from '../../../../withFeature';
import type { NavigationActionCreatorsMap, NavigationStore } from '../..';
import reducer, { defaultNavigationStore } from './reducer';
/** Remote UI doesn't support passing an `URL` through so this is
 * more limited than the App Bridge Client useNavigate interface
 */
export type To = Location | string;
export interface WithFeature {
    actions: NavigationActionCreatorsMap;
    store: NavigationStore;
    api: {
        navigate: Navigate<To>;
    };
}
/**
 * An object containing the key, actions, initial state and reducer of the Navigation feature
 * Can be used with the `withFeature` decorator to add the reducer
 * and then make its actions and store available to the wrapped component
 * @public
 * */
export declare const feature: FeatureWithRouterApi<WithFeature['store'], WithFeature['actions'], WithFeature['api']>;
export default reducer;
export * from './actionCreators';
export * from './actions';
export * from './types';
export { defaultNavigationStore };
