import type { PickerApi } from '@shopify/app-bridge-core/actions/Picker';
import type { FeatureWithApi } from '../../../../withFeature';
import { PickerActionCreatorsMap } from './actionCreators';
import reducer, { defaultPickerStore } from './reducer';
import { PickerStore } from './types';
/**
 * The interface props that are passed down to the Picker component
 * as a the result of calling the `withFeature` decorator
 * @public
 * */
export interface WithFeature {
    store: PickerStore | null;
    actions: PickerActionCreatorsMap;
    api: PickerApi;
}
/**
 * An object containing the key, actions, initial state and reducer of the Picker feature
 * Can be used with the `withFeature` decorator to add the reducer
 * and then make its actions and store available to the wrapped component
 * @public
 * */
export declare const feature: FeatureWithApi<WithFeature['store'], WithFeature['actions'], WithFeature['api']>;
export default reducer;
export * from './actionCreators';
export * from './types';
export { defaultPickerStore };
