import type { Feature } from '../../../../withFeature';
import { ResourcePickerActionCreatorsMap } from './actionCreators';
import reducer, { defaultResourcePickerStore } from './reducer';
import { ResourcePickerStore } from './types';
/**
 * The interface props that are passed down to the ResourcePicker component
 * as a the result of calling the `withFeature` decorator
 * @public
 * */
export interface WithFeature {
    store: ResourcePickerStore | null;
    actions: ResourcePickerActionCreatorsMap;
}
/**
 * An object containing the key, actions, initial state and reducer of the ResourcePicker feature
 * Can be used with the `withFeature` decorator to add the reducer
 * and then make its actions and store available to the wrapped component
 * @public
 * */
export declare const feature: Feature<WithFeature['store'], WithFeature['actions']>;
export default reducer;
export * from './actionCreators';
export * from './types';
export { defaultResourcePickerStore };
