import type { TitleBarApi } from '@shopify/app-bridge-core/actions/TitleBar';
import type { FeatureWithApi } from '../../../../withFeature';
import { TitleBarActionCreatorsMap } from './actionCreators';
import reducer, { defaultTitlebarStore } from './reducer';
import { TitleBarStore } from './types';
export default reducer;
export * from './actionCreators';
export * from './actions';
export * from './types';
export { defaultTitlebarStore };
/**
 * The interface props that are passed down to the TitleBar component
 * as a the result of calling the `withFeature` decorator
 * @public
 * */
export interface WithFeature {
    store: TitleBarStore | null;
    actions: TitleBarActionCreatorsMap;
    api: TitleBarApi;
}
export type TitleBarFeature = FeatureWithApi<WithFeature['store'], WithFeature['actions'], WithFeature['api']>;
/**
 * An object containing the key, actions, initial state and reducer of the TitleBar feature
 * Can be used with the `withFeature` decorator to add the reducer
 * and then make its actions and store available to the wrapped component
 * @public
 * */
export declare const feature: TitleBarFeature;
